---
title: Urubu 0.6 released
layout: page 
date: 2015-01-28
---

Urubu 0.6 improves on wiki links: now you can link to a location within a page. 

Read [my blog post][post] for more info.

[post]: http://www.jandecaluwe.com/blog/urubu-0-6.html




